%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bvqxprotocol_to_bvqxdesignmatrix.m
% Script to create a design matrix from a stimulation protocol in Matlab
% Works with BrainVoyager QX 1.9
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXInterface.1')
[vmrName, vmrDir] = uigetfile('*.vmr','Please select the VMR file...');
vmrfilename = [vmrDir vmrName];
vmrproject = bvqx.OpenDocument(vmrfilename);
bvqx.ResizeWindow(600,400);
[vtcName, vtcDir] = uigetfile('*.vtc','Please select the VTC file...');
vtcfilename = [vtcDir vtcName];
vmrproject.LinkVTC(vtcName); % only filename, not pathname
vmrproject.LinkStimulationProtocol('uncertainty_all_200ms.prt');
vmrproject.ClearDesignMatrix;
vmrproject.AddPredictor('ImgsCertain');
vmrproject.AddPredictor('ImgsUncertain');
vmrproject.AddPredictor('DeclQuestions');
vmrproject.SetPredictorValuesFromCondition('ImgsCertain', 'ImagesCertain', 1.0);
vmrproject.SetPredictorValuesFromCondition('ImgsUncertain', 'ImagesUncertain', 1.0);
vmrproject.SetPredictorValuesFromCondition('DeclQuestions', 'DeclarativeQuestions', 1.0);
vmrproject.ApplyHemodynamicResponseFunctionToPredictor('ImgsCertain');
vmrproject.ApplyHemodynamicResponseFunctionToPredictor('ImgsUncertain');
vmrproject.ApplyHemodynamicResponseFunctionToPredictor('DeclQuestions');
vmrproject.SaveSingleStudyGLMDesignMatrix('uncertainty_all.rtc');
vmrproject.CorrectForSerialCorrelations = true;
vmrproject.ComputeSingleStudyGLM;
vmrproject.ShowGLM;
