
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute_glm_display_betaweights.m
% Script to compute a GLM, reads it in Matlab via the BVQXtools (see wiki)
% and display the betaweights in Matlab
% 
% Works with BrainVoyager QX 1.9 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[FileName,PathName] = uigetfile('*.fmr','Please select the functional data file...');
fmrfilename = strcat(PathName, FileName);
[FileName,PathName] = uigetfile('*.prt','Please select the protocol file...');
prtfilename = strcat(PathName, FileName);
[FileName,PathName] = uigetfile('*.rtc','Please select the design matrix file...');
rtcfilename = strcat(PathName, FileName);

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXInterface.1');
bvqx.ShowLogTab;
bvqx.PrintToLog('Start computing GLM from Matlab...');
fmrproject = bvqx.OpenDocument(fmrfilename);
fmrproject.LinkStimulationProtocol(prtfilename);
fmrproject.CorrectForSerialCorrelations 	= 1;
fmrproject.PSCTransformStudies              = 1;
bvqx.PrintToLog(['Loading ' rtcfilename '...']);
fmrproject.LoadSingleStudyGLMDesignMatrix(rtcfilename);	% design matrix (*.rtc)
fmrproject.ComputeSingleStudyGLM();		
fmrproject.ShowGLM();
[pathstr,name,ext,versn] = fileparts(fmrfilename);
glmfilename = fullfile(pathstr, [name '.glm']);
bvqx.PrintToLog(['Saving ' glmfilename '...']);	
fmrproject.SaveGLM(glmfilename);  

answer = questdlg('Close project?', 'Compute GLM');
if answer == 'Yes'
    fmrproject.Close;
end

% Now read the GLM file in via BVQXtools
h = msgbox('Please select the BVQXtools directory');
uiwait(h);
addpath(uigetdir);
glm = BVQXFile('GLM');     
glm = BVQXfile(glmfilename);
glm.GLMData % shows fields in structure
betaweights4d = glm.GLMData.BetaMaps;
volsize = size(betaweights4d)
slicenr = num2str(floor(volsize(3)/2));
betaweights2d = betaweights4d(:,:,floor(volsize(3)/2),1);
figure;
subplot(1,2,1); surf(double(betaweights2d)); 
title(['surface plot of beta values slice ' slicenr ' map 1']); axis image xy off 
subplot(1,2,2); contour(betaweights2d); 
title(['contourplot of beta values slice ' slicenr ' map 1']); axis image xy off 

