%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create_vmrproject_via_interface.m
% Script to create a BrainVoyager VMR project in Matlab
% Works with BrainVoyager QX 1.9
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXInterface.1')
h = msgbox('This script creates a BrainVoyager anatomical volume (*.vmr) file. Please select the first raw data file...', 'Create VMR project');
uiwait(h);
cancel = 0;

% get first file
[filename, pathname] = uigetfile( ...
    {'*.dcm; *.IMA; *.I; *.MR; *.REC;*.hdr','Raw data files (*.dcm,*.IMA,*.I, *.MR, *.REC,*.hdr)';
    '*.dcm',  'DICOM files (*.dcm)'; ...
        '*.IMA','Siemens DICOM files (*.IMA)'; ...
        '*.I','GE I files (*.I)'; ...
        '*.MR','GE MR (*.MR)'; ...
        '*.REC','Philips files (*.REC)'; ...
        '*.hdr','Analyze (*.hdr)'}, ...
    'Please select the first file');
firstfilename = strcat(pathname, filename);
[pathstr,name,ext,versn] = fileparts(firstfilename);
switch ext
    case '.dcm', filetype = 'DICOM'
    case '.IMA', filetype = 'SIEMENS'
    case '.I', filetype = 'GE_I'
    case '.MR', filetype = 'GE_MR'
    case '.REC', filetype = 'PHILIPS_REC'
    case '.hdr', filetype = 'ANALYZE'
    otherwise cancel = 1
end

if ~cancel
    % get parameters 
    
    if (strcmp(ext, '.dcm') == 1) && (exist('dicominfo.m') > 0) 
        dcminfo = dicominfo(firstfilename);
        bytesperpixel = (dcminfo.BitsAllocated/8);
        xres = dcminfo.Columns;
        yres = dcminfo.Rows;
    else
        prompt = {'Please enter the size of the x-axis','Please enter the size of the y-axis', 'Please enter the size of the number of bytes'};
        dlgtitle = 'Parameters for VMR project';
        nrlines = 1;
        def     = {'256','256', '2'};
        answer  = inputdlg(prompt,dlgtitle,nrlines,def);
        xres = answer{1};
        yres = answer{2};
        bytesperpixel = answer{3};    
    end
    
    button = questdlg('Are there only raw data files for a VMR project in this directory?',...
        'Create VMR script','Yes','No','Yes');
    if strcmp(button,'Yes')
        rawfileselection = [pathname ['*' ext]];
        files = dir(rawfileselection);
        sizeAr = size(files);
        nrslices = sizeAr(1);    
    else
        answer = inputdlg('Please enter the number of slices');
        nrslices = answer{1};
    end
    
    button = questdlg('Swap data?', 'Create VMR script','Yes','No','No');
    if strcmp(button,'Yes'), swap = 1; else swap = 0; end;
    
    vmrproject = bvqx.CreateProjectVMR(filetype, firstfilename, nrslices, swap, xres, yres, bytesperpixel);
    success = vmrproject.SaveAs(fullfile(pathname, [name '.vmr']));
    
end

