
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% meshes.m
% Script to visualize a mesh with different axes in Matlab
% >> zie ook email van Elia aan Kate
% Works with BrainVoyager QX 1.9 with *.srf files at least up to version 4.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[FileName,PathName] = uigetfile('*.srf','Please select the *.srf file...');
srfFile = strcat(PathName, FileName);
fid=fopen(srfFile,'rb'); % read only
%%%%% read in header data %%%%%
version_number = fread(fid, [1 1], 'float32'); % version number of surface file; default: 3
reserved = fread(fid, [1 1], 'uint32'); % reserved, must be '0'
NrOfVertices = fread(fid, [1 1], 'uint32'); % number of vertices
NrOfTriangles = fread(fid, [1 1], 'uint32'); % number of triangles

% COORDINATE VALUES
MeshCenterX = fread(fid, [1 1], 'float32'); % center of mesh on X-axis; default coordinate: 128
MeshCenterY = fread(fid, [1 1], 'float32'); % center of mesh on Y-axis; default coordinate: 128
MeshCenterZ = fread(fid, [1 1], 'float32'); % center of mesh on Z-axis; default coordinate: 128
VertexX = fread(fid, [1 NrOfVertices], 'float32'); % sequence of X coordinates of all vertices
VertexY = fread(fid, [1 NrOfVertices], 'float32'); % sequence of Y coordinates of all vertices
VertexZ = fread(fid, [1 NrOfVertices], 'float32'); % sequence of Z coordinates of all vertices
NormalX = fread(fid, [1 NrOfVertices], 'float32'); % sequence of X components of all vertex normals
NormalY = fread(fid, [1 NrOfVertices], 'float32'); % sequence of Y components of all vertex normals
NormalZ = fread(fid, [1 NrOfVertices], 'float32'); % sequence of Z components of all vertex normals

% COLORS OF THE SURFACE
RedConvCurv = fread(fid, [1 1], 'float32'); % R component of convex curvature color (range: 0.0 - 1-0); default: 0.322
GreenConvCurv = fread(fid, [1 1], 'float32'); % G component of convex curvature color (range: 0.0 - 1-0); default: 0.733
BlueConvCurv = fread(fid, [1 1], 'float32'); % B component of convex curvature color (range: 0.0 - 1-0); default: 0.980
AlphaConvCurv = fread(fid, [1 1], 'float32'); %  Alpha component of convex curvature color (range: 0.0 - 1-0); default: 0.500
RedConvCurv = fread(fid, [1 1], 'float32'); % R component of convex curvature color (range: 0.0 - 1-0); default: 0.100
GreenConcCurv = fread(fid, [1 1], 'float32'); % G component of concave curvature color (range: 0.0 - 1-0); default: 0.240
BlueConcCurv = fread(fid, [1 1], 'float32'); % B component of concave curvature color (range: 0.0 - 1-0); default: 0.320
AlphaConcCurv = fread(fid, [1 1], 'float32'); %  Alpha component of concave curvature color (range: 0.0 - 1-0); default: 0.500
MeshColor = fread(fid, [1 NrOfVertices], 'int32'); % sequence of color indices of all vertices (*1)

% ALL VERTEX VALUES
vertexNeighbours = struct('VertexNr',{}, 'NrNeighbours',{},'Neighbours',{}); 
for vertexCounter=1:NrOfVertices 
    vertexNeighbours(vertexCounter).VertexNr = vertexCounter;
    NrOfNeighbours = fread(fid, [1 1], 'int32'); 
    vertexNeighbours(vertexCounter).NrNeighbours = NrOfNeighbours;
    vertexNeighbours(vertexCounter).Neighbours = fread(fid, [1 NrOfNeighbours], 'int');
end
% TriangleSequence = fread(fid, [1 NrOfTriangles*3], 'int'); % Sequence of three indices to constituting vertices of each triangle
% NrOfTriangleStripElements = fread(fid, [1 1], 'int'); % Number of triangle strip elements
% if (NrOfTriangleStripElements > 0)
%     StripElemSequence = fread(fid, [1 NrOfTriangleStripElements], 'int32'); % Sequence of strip elements 
% end
fclose(fid);
% (*1) Each vertex has one color index. An index value of 0 references the convex curvature color, 
% a value of 1 references the concave curvature color. Functional colors, RGB colors can be also represented. 

% example from Matlab on multiple axes
tris = reshape(TriangleSequence,3,[])'+1;
figure;
h(1) = axes('Position',[0 0 1 1]);
trimesh(tris, VertexX',VertexY',VertexZ'); 
h(2) = axes('Position',[0 0 .4 .6]); % closer, on the left lower corner
%sphere
trimesh(tris, VertexX',VertexY',VertexZ'); 
h(3) = axes('Position',[0 .5 .5 .5]); % closer, on the left upper corner, stretched
trimesh(tris, VertexX',VertexY',VertexZ'); 
h(4) = axes('Position',[.5 0 .4 .4]); % closer, on the right lower corner, stretched
trimesh(tris, VertexX',VertexY',VertexZ'); 
h(5) = axes('Position',[.5 .5 .5 .3]); % closer, on the right upper corner, very stretched
trimesh(tris, VertexX',VertexY',VertexZ'); 
set(h,'Visible','off')