%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% presentation_to_bvqxprotocol.m; script to read Presentation Log file and create stimulation protocol in Matlab
% Works with BrainVoyager QX 1.9
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bvqx = actxserver('BrainVoyagerQX.BrainVoyagerQXInterface.1')
[presName, presDir] = uigetfile('*.log','Please select the Presentation log file...');
presfilename = [presDir presName];
presFile2 = textread(presfilename,'%s','delimiter','\t','whitespace',''); % reading with tabs
stimProt = struct('Trialnr',{},'Eventname',{}, 'EventOffsetInMSec',{}, 'EventOffsetInSec',{}, 'EventOffsetInMin',{}, ...
'DurationOfEventInMsec',{}, 'DurationOfEventInSec',{});
eventnr = 1;
for i=1:length(presFile2);
    value = presFile2{i};
    if ~isempty(strfind(value, 'Picture'))
        stimProt(eventnr).Trialnr = presFile2{i-1};
        stimProt(eventnr).Eventname = presFile2{i+1};
        offtsms = str2num(presFile2{i+2});
        stimProt(eventnr).EventOffsetInMSec = (offtsms / 10);
        stimProt(eventnr).EventOffsetInSec = (offtsms / 1000 / 10);
        stimProt(eventnr).EventOffsetInMin = (stimProt(eventnr).EventOffsetInSec / 60);
        stimProt(eventnr).DurationOfEventInMsec = (str2num(presFile2{i+5}) / 10);
        stimProt(eventnr).DurationOfEventInSec = (str2num(presFile2{i+5}) / 1000 / 10);
        eventnr = eventnr + 1;
    end
end;
% methodlist = invoke(bvqx);
[vmrName, vmrDir] = uigetfile('*.vmr','Please select the VMR file...');
vmrfilename = [vmrDir vmrName];
vmrproject = bvqx.OpenDocument(vmrfilename);
bvqx.ResizeWindow(600,400);
[vtcName, vtcDir] = uigetfile('*.vtc','Please select the VTC file...');
vtcfilename = [vtcDir vtcName];
vmrproject.LinkVTC(vtcName); % only filename, not pathname

vmrproject.ClearStimulationProtocol;
vmrproject.StimulationProtocolExperimentName = 'Objects_in_VF';
vmrproject.AddCondition('LVF');
vmrproject.SetConditionColor('Objects in LVF', 255,0,0); % red
vmrproject.AddCondition('RVF');
vmrproject.SetConditionColor('Objects in RVF', 0,255,0); % green
vmrproject.AddCondition('BVF');
vmrproject.SetConditionColor('Objects in BVF', 0,0,255); % blue
vmrproject.AddCondition('Fixation');
vmrproject.SetConditionColor('Fixation', 192,192,192); % gray

% go through all the 'Picture' objects in the 'stimProt' structure to assign them as intervals to the different conditions
Picture_LVF = 'LVF';
Picture_RVF = 'RVF';
Picture_BVF = 'BVF';
for i=1:length(stimProt)
    if (strfind(stimProt(i).Eventname, Picture_LVF) > 0)
       vmrproject.AddInterval('LVF', stimProt(i).EventOffsetInMSec, (stimProt(i).EventOffsetInMSec+stimProt(i).DurationOfEventInMsec));
   elseif (strfind(stimProt(i).Eventname, Picture_RVF) > 0) 
       vmrproject.AddInterval('RVF', stimProt(i).EventOffsetInMSec, (stimProt(i).EventOffsetInMSec+stimProt(i).DurationOfEventInMsec));
    elseif (strfind(stimProt(i).Eventname, Picture_BVF) > 0)
       vmrproject.AddInterval('BVF', stimProt(i).EventOffsetInMSec, (stimProt(i).EventOffsetInMSec+stimProt(i).DurationOfEventInMsec));
    end;
end
vmrproject.SaveStimulationProtocol('cgobjects_frommatlab.prt');
%vmrproject.LoadStimulationProtocol('cgobjects_frommatlab.prt');
%vmrproject.Close;
